/*
 * Copyright (c) 2025 by Martin Guy <martinwguy@gmail.com>
 * 
 * Permission to use, copy, modify, and distribute this software
 * for any purpose with or without fee is hereby granted,
 * provided that this notice is not removed and that the author is
 * not deemed to have made any representations as to the suitability
 * of this software for any purpose nor are held responsible
 * for any defects of this software.  THERE IS ABSOLUTELY NO
 * WARRANTY FOR THIS SOFTWARE.
 */

#ifndef	CONFIG_H
#define	CONFIG_H

#include "../src/soxconfig.h"

#define HAS_STDLIB_H HAVE_STDLIB_H
#define HAS_STRING_H HAVE_STRING_H
#define HAS_MALLOC_H HAVE_MALLOC_H

#endif	/* CONFIG_H */
