#define gsm_add lsx_gsm_add
#define gsm_sub lsx_gsm_sub
#define gsm_mult lsx_gsm_mult
#define gsm_mult_r lsx_gsm_mult_r
#define gsm_abs lsx_gsm_abs
#define gsm_L_mult lsx_gsm_L_mult
#define gsm_L_add lsx_gsm_L_add
#define gsm_L_sub lsx_gsm_L_sub
#define gsm_norm lsx_gsm_norm
#define gsm_L_asl lsx_gsm_L_asl
#define gsm_L_asr lsx_gsm_L_asr
#define gsm_asl lsx_gsm_asl
#define gsm_asr lsx_gsm_asr
#define gsm_div lsx_gsm_div
#define Gsm_Coder lsx_Gsm_Coder
#define Gsm_Decoder lsx_Gsm_Decoder
#define gsm_create lsx_gsm_create
#define gsm_decode lsx_gsm_decode
#define gsm_destroy lsx_gsm_destroy
#define gsm_encode lsx_gsm_encode
#define gsm_option lsx_gsm_option
#define Gsm_Long_Term_Predictor lsx_Gsm_Long_Term_Predictor
#define Gsm_Long_Term_Synthesis_Filtering lsx_Gsm_Long_Term_Synthesis_Filtering
#define Gsm_LPC_Analysis lsx_Gsm_LPC_Analysis
#define Gsm_Preprocess lsx_Gsm_Preprocess
#define Gsm_RPE_Encoding lsx_Gsm_RPE_Encoding
#define Gsm_RPE_Decoding lsx_Gsm_RPE_Decoding
#define Gsm_Short_Term_Analysis_Filter lsx_Gsm_Short_Term_Analysis_Filter
#define Gsm_Short_Term_Synthesis_Filter lsx_Gsm_Short_Term_Synthesis_Filter
#define gsm_A lsx_gsm_A
#define gsm_B lsx_gsm_B
#define gsm_MIC lsx_gsm_MIC
#define gsm_MAC lsx_gsm_MAC
#define gsm_INVA lsx_gsm_INVA
#define gsm_DLB lsx_gsm_DLB
#define gsm_QLB lsx_gsm_QLB
#define gsm_H lsx_gsm_H
#define gsm_NRFAC lsx_gsm_NRFAC
#define gsm_FAC lsx_gsm_FAC

